@@ -29,14 +29,8 @@ from lightbulb import errors
 from lightbulb import converters
 from lightbulb import cooldowns
 
-__all__: typing.Final[typing.Tuple[str]] = (
-    "ArgInfo",
-    "SignatureInspector",
-    "Command",
-    "Group",
-    "command",
-    "group",
-)
+if not typing.TYPE_CHECKING:
+    from lightbulb import plugins
 
 __all__: typing.Final[typing.Tuple[str]] = (
     "ArgInfo",
@@ -206,9 +200,13 @@ class Command:
         self._aliases = aliases
         self._checks = []
         self.method_name: typing.Optional[str] = None
-        self.parent = parent
+        self.parent: typing.Optional[typing.Any] = parent
+        """The parent group for the command. If ``None`` then the command is not a subcommand."""
+        self.plugin: typing.Optional[plugins.Plugin] = None
+        """The plugin the command is registered to. If ``None`` then it was defined outside of a plugin."""
 
         self.cooldown_manager: typing.Optional[cooldowns.CooldownManager] = None
+        """The cooldown manager being used for the command. If ``None`` then the command does not have a cooldown."""
 
         signature = inspect.signature(callback)
         self._has_max_args = not any(
@@ -355,10 +353,12 @@ class Group(Command):
         **kwargs: The kwargs passed to :obj:`~.commands.Command` in its constructor
     """
 
-    def __init__(self, *args, insensitive_commands: bool = False, **kwargs) -> None:
+    def __init__(self, *args, insensitive_commands: bool = False, inherit_checks: bool = True, **kwargs) -> None:
         super().__init__(*args, **kwargs)
         self.insensitive_commands = insensitive_commands
-        self.subcommands = {} if not self.insensitive_commands else CIMultiDict()
+        self.inherit_checks = inherit_checks
+        self.subcommands: typing.MutableMapping[str, Command] = {} if not self.insensitive_commands else CIMultiDict()
+        """A mapping of command name to command object containing the subcommands registered to the group."""
 
     def _resolve_subcommand(self, args) -> typing.Tuple[typing.Union[Command, Group], typing.Iterable[str]]:
         this = self
@@ -375,6 +375,12 @@ class Group(Command):
 
         return this, args
 
+    def add_check(self, check_func: typing.Callable[[context.Context], typing.Coroutine[None, None, bool]]) -> None:
+        if self.inherit_checks:
+            for c in set(self.subcommands.values()):
+                c.add_check(check_func)
+        super().add_check(check_func)
+
     def get_subcommand(self, name: str) -> Command:
         """
         Get a command object for a subcommand of the group from it's registered name.
@@ -420,6 +426,8 @@ class Group(Command):
             subcommands[name] = cls(
                 func, name, kwargs.get("allow_extra_arguments", True), kwargs.get("aliases", []), parent=self,
             )
+            if self.inherit_checks:
+                subcommands[name]._checks.extend(self._checks)
             for alias in kwargs.get("aliases", []):
                 subcommands[alias] = subcommands[name]
             return subcommands[name]
@@ -436,8 +444,29 @@ class Group(Command):
             name (:obj:`str`): Optional name of the command. Defaults to the name of the function if not specified.
             aliases (Optional[ Iterable[ :obj:`str` ] ]): An iterable of aliases which can also invoke the command.
         """
+        subcommands = self.subcommands
         kwargs["cls"] = type(self)
-        return self.command(**kwargs)
+
+        def decorate(func):
+            nonlocal subcommands
+            name = kwargs.get("name", func.__name__)
+            cls = kwargs.get("cls", Group)
+            subcommands[name] = cls(
+                func,
+                name,
+                kwargs.get("allow_extra_arguments", True),
+                kwargs.get("aliases", []),
+                insensitive_commands=kwargs.get("insensitive_commands", False),
+                inherit_checks=kwargs.get("inherit_checks", True),
+                parent=self,
+            )
+            if self.inherit_checks:
+                subcommands[name]._checks.extend(self._checks)
+            for alias in kwargs.get("aliases", []):
+                subcommands[alias] = subcommands[name]
+            return subcommands[name]
+
+        return decorate
 
 
 def command(**kwargs):
@@ -456,7 +485,7 @@ def command(**kwargs):
     def decorate(func):
         name = kwargs.get("name", func.__name__)
         cls = kwargs.get("cls", Command)
-        return cls(func, name, kwargs.get("allow_extra_arguments", True), kwargs.get("aliases", []),)
+        return cls(func, name, kwargs.get("allow_extra_arguments", True), kwargs.get("aliases", []))
 
     return decorate
 
@@ -470,8 +499,11 @@ def group(**kwargs):
         allow_extra_arguments (Optional[ :obj:`bool` ]): Whether or not the command should error when run with
             more arguments than it takes. Defaults to True - will not raise an error.
         aliases (Optional[ Iterable[ :obj:`str` ] ]): Iterable of aliases which will also invoke the command.
+        insensitive_commands (:obj:`bool`): Whether or not subcommands should be case-insensitive. Defaults to
+            False.
         cls (:obj:`~.commands.Command`): The class to use to instantiate the group object from. Defaults
             to :obj:`~.commands.Group`.
+        inherit_checks (:obj:`bool`): Whether or not subcommands should inherit checks added to the base group.
     """
 
     def decorate(func):
@@ -483,6 +515,7 @@ def group(**kwargs):
             kwargs.get("allow_extra_arguments", True),
             kwargs.get("aliases", []),
             insensitive_commands=kwargs.get("insensitive_commands", False),
+            inherit_checks=kwargs.get("inherit_checks", True),
         )
 
     return decorate
